ExtensionBuilder<T extends ExtensionDescriptor> class abstract

The base type for all extension builders. An extension builder is responsible for building an extension, by assembling all of the extension descriptors.

Constructors

ExtensionBuilder({required Type extensionType, required String title})
Creates a new ExtensionBuilder.

Properties

extensionType → Type
The runtime Type of the extension.
final
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether the extension has been disposed.
no setter
isInitialized → bool
Whether the extension is currently initialized.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceFeature → String?
The name of the feature which this extension belongs to. This is set by the bootstrapping process of Vyuh.
no setter
title → String
The title of the extension.
final

Methods

dispose() → Future<void>
Disposes the extension.
init(List<ExtensionDescriptor> extensions) → Future<void>
Initializes the extension.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() → Future<void>
Protected method for subclasses to implement disposal logic.
onInit(List<T> extensions) → Future<void>
Protected method for subclasses to implement initialization logic.
registerLazy(ExtensionDescriptor descriptor) → void
Registers extensions from a lazily-loaded feature. Override in subclasses that support incremental registration. By default this is a no-op.
setSourceFeature(String featureName) → void
Sets the source feature for this extension builder. This is called by the Vyuh bootstrapping process.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited