ExtensionDescriptor class abstract

The base type for all extension descriptors. An ExtensionDescriptor provides configurability for an extension.

Constructors

ExtensionDescriptor({required String title})
Creates a new ExtensionDescriptor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceFeature → String?
The name of the feature which this extension belongs to. This is set by the Vyuh bootstrapping process
no setter
title → String
The title of the extension.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSourceFeatureUpdated() → void
setSourceFeature(String featureName) → void
Sets the source feature for this extension. This is called by the Vyuh bootstrapping process.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited