FeatureDescriptor class final

The essential descriptor for a feature. A feature descriptor provides the necessary information to register a feature within the framework.

Constructors

FeatureDescriptor({required String name, required String title, String? description, IconData? icon, VoidFutureFunction? init, VoidFutureFunction? dispose, required RouteBuilderFunction routes, List<ExtensionDescriptor>? extensions, List<ExtensionBuilder<ExtensionDescriptor>>? extensionBuilders, List<String> dependencies = const []})
Creates a new FeatureDescriptor.

Properties

dependencies → List<String>
Optional list of feature names that must be initialized before this feature. Used for ordering during initialization. If empty (the default), no ordering constraint is applied.
final
description → String?
The description of the feature.
final
dispose → VoidFutureFunction?
The function to dispose the feature.
final
extensionBuilders → List<ExtensionBuilder<ExtensionDescriptor>>?
The list of extension builders exposed by this feature.
final
extensions → List<ExtensionDescriptor>?
The list of extensions for the feature.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
The icon of the feature.
final
init → VoidFutureFunction?
The function to initialize the feature.
final
name → String
The name of the feature.
final
routes → RouteBuilderFunction?
The routes for the feature.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
The title of the feature.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited