AnalyticsProvider class abstract interface

The base interface for an Analytics Provider. The provider is responsible for reporting analytics events, errors, and messages.

Implementers

Properties

description → String
The description of the provider.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the provider.
no setter
observers → List<NavigatorObserver>
The list of observers for the provider. These are added to the navigator, as part of the router setup.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
The title of the provider.
no setter

Methods

dispose() → Future<void>
Disposes the provider.
identifyUser(String userId, {Map<String, dynamic>? traits}) → Future<void>
Identifies a user with the given ID and optional traits. The traits can include any user properties like email, name, etc.
init() → Future<void>
Initializes the provider.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportEvent(String name, {Map<String, dynamic>? params}) → Future<void>
Reports an event with a specific name and optional parameters.
resetUser() → Future<void>
Clears the current user identification and associated traits. This should be called when the user logs out.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited