NoOpAnalyticsProvider class final

A no-op implementation of AnalyticsProvider.

Implemented types

Constructors

NoOpAnalyticsProvider()

Properties

description → String
The description of the provider.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the provider.
no setteroverride
observers → List<NavigatorObserver>
The list of observers for the provider. These are added to the navigator, as part of the router setup.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
The title of the provider.
no setteroverride

Methods

dispose() → Future<void>
Disposes the provider.
override
identifyUser(String userId, {Map<String, dynamic>? traits}) → Future<void>
Identifies a user with the given ID and optional traits. The traits can include any user properties like email, name, etc.
override
init() → Future<void>
Initializes the provider.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportEvent(String name, {Map<String, dynamic>? params}) → Future<void>
Reports an event with a specific name and optional parameters.
override
resetUser() → Future<void>
Clears the current user identification and associated traits. This should be called when the user logs out.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited