UnknownAuthPlugin class final

An authentication plugin that does not support any authentication methods.

Inheritance

Constructors

UnknownAuthPlugin()
Creates an instance of UnknownAuthPlugin.

Properties

controller ↔ StreamController<User>
The controller for the user changes stream.
getter/setter pairinherited
currentUser → User
The current user that is signed in.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
refreshToken → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
finalinherited
token → String
no setteroverride
userChanges → Stream<User>
A stream of user changes.
no setterinherited

Methods

deleteAccount() → Future<void>
Deletes the current user account.
inherited
dispose() → Future<void>
inherited
init() → Future<void>
inherited
loginAnonymously() → Future<void>
inherited
inherited
loginWithEmailPassword({required String email, required String password}) → Future<void>
inherited
loginWithOAuth(OAuthType type) → Future<void>
inherited
loginWithPhoneOtp({required String phoneNumber, required String otp}) → Future<void>
inherited
logout() → Future<void>
Logs out the current user.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshSession() → Future<bool>
Attempts to refresh the current session token.
inherited
registerWithEmailPassword({required String email, required String password}) → Future<void>
inherited
inherited
sendOtp({required String phoneNumber}) → Future<void>
inherited
sendPasswordResetEmail({required String email}) → Future<void>
inherited
setCurrentUser(User user) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited