AuthPlugin class abstract

An authentication plugin that supports various authentication methods.

Inheritance
Implementers

Constructors

AuthPlugin({required String name, required String title})
Creates an instance of AuthPlugin.

Properties

controller ↔ StreamController<User>
The controller for the user changes stream.
getter/setter pair
currentUser → User
The current user that is signed in.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
refreshToken → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
finalinherited
token → String
no setter
userChanges → Stream<User>
A stream of user changes.
no setter

Methods

deleteAccount() → Future<void>
Deletes the current user account.
dispose() → Future<void>
override
init() → Future<void>
override
loginAnonymously() → Future<void>
loginWithEmailPassword({required String email, required String password}) → Future<void>
loginWithOAuth(OAuthType type) → Future<void>
loginWithPhoneOtp({required String phoneNumber, required String otp}) → Future<void>
logout() → Future<void>
Logs out the current user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshSession() → Future<bool>
Attempts to refresh the current session token.
registerWithEmailPassword({required String email, required String password}) → Future<void>
sendOtp({required String phoneNumber}) → Future<void>
sendPasswordResetEmail({required String email}) → Future<void>
setCurrentUser(User user) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited