DeleteAccountFailure class final

Exception thrown when the account deletion fails.

Inheritance

Constructors

DeleteAccountFailure(Object error)
Create a new DeleteAccountFailure with the given error.
const

Properties

error → Object
The error that caused this exception.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited