LoginMethodCanceled class final

Exception thrown when a login method is canceled.

Inheritance

Constructors

LoginMethodCanceled(LoginMethod method, Object error)
Create a new LoginMethodCanceled with the given method and error.
const

Properties

error → Object
The error that caused this exception.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
method → LoginMethod
The login method that was canceled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited