LoginMethod enum

Represents the method used to login.

Inheritance
Available extensions

Values

unknown → const LoginMethod

The method is unknown.

anonymous → const LoginMethod

The user is anonymous.

emailPassword → const LoginMethod

The user logged in using email and password.

phoneOtp → const LoginMethod

The user logged in using phone OTP.

The user logged in using email link.

google → const LoginMethod

The user logged in using Google.

facebook → const LoginMethod

The user logged in using Facebook/Meta

apple → const LoginMethod

The user logged in using Apple.

twitter → const LoginMethod

The user logged in using Twitter.

github → const LoginMethod

The user logged in using GitHub.

linkedin → const LoginMethod

The user logged in using LinkedIn.

microsoft → const LoginMethod

The user logged in using Microsoft.

custom → const LoginMethod

The user logged in using a custom method.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

icon() → IconData
Returns the icon for this login method. This is useful only in the developer tools or UI.
label() → String
Returns the label for this login method. This is useful only in the developer tools or UI.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<LoginMethod>
A constant List of the values in this enum, in order of their declaration.