User class

Represents a user of the application.

Constructors

User({required LoginMethod loginMethod, required String id, String? name, String? email, String? phoneNumber, String? photoUrl, DateTime? lastSignInTime, DateTime? creationTime})
Create a new user with the given parameters.
const

Properties

creationTime → DateTime?
The creation time of the user.
final
email → String?
The email of the user.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the user.
final
isUnknown → bool
Returns true if this user is the unknown user.
no setter
lastSignInTime → DateTime?
The last sign-in time of the user.
final
loginMethod → LoginMethod
The method used to login.
final
name → String?
The name of the user. This could include the first name, last name or display name.
final
phoneNumber → String?
The phone number of the user.
final
photoUrl → String?
The URL of the user's photo.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

unknown → const User
A constant unknown user.