ActionFailure class final

Failure when an action configuration registration is missing.

This occurs when content references an action that has no registered TypeDescriptor in the action system.

Inheritance

Constructors

ActionFailure({required String schemaType, Map<String, dynamic>? actionConfig, Map<String, dynamic>? jsonPayload, String? description, List<String>? suggestions})
const

Properties

actionConfig → Map<String, dynamic>?
The action configuration that failed to resolve
final
description → String?
Human-readable description of the failure
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
jsonPayload → Map<String, dynamic>?
The original JSON payload that caused the failure (if available)
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
The schema type that failed to resolve
finalinherited
suggestions → List<String>?
Optional suggestions for resolving the failure
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited