LayoutFailure class final

Failure when a layout for a registered content type is missing.

This occurs when a ContentItem has been successfully deserialized but no layout configuration can be found to render it.

Inheritance

Constructors

LayoutFailure({required String schemaType, required String contentSchemaType, String? requestedLayoutType, Map<String, dynamic>? jsonPayload, String? description, List<String>? suggestions})
const

Properties

contentSchemaType → String
The content type that needs a layout
final
description → String?
Human-readable description of the failure
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
jsonPayload → Map<String, dynamic>?
The original JSON payload that caused the failure (if available)
finalinherited
requestedLayoutType → String?
The specific layout type that was requested (if any)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
The schema type that failed to resolve
finalinherited
suggestions → List<String>?
Optional suggestions for resolving the failure
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited