ModifierFailure class final

Failure when a content modifier registration is missing.

This occurs when applying a chain of modifiers to content and one of the modifiers in the chain cannot be resolved.

Inheritance

Constructors

ModifierFailure({required String schemaType, required List<String> modifierChain, required int failedIndex, Map<String, dynamic>? jsonPayload, String? description, List<String>? suggestions})
const

Properties

description → String?
Human-readable description of the failure
finalinherited
failedIndex → int
The index in the modifier chain where the failure occurred
final
hashCode → int
The hash code for this object.
no setterinherited
jsonPayload → Map<String, dynamic>?
The original JSON payload that caused the failure (if available)
finalinherited
modifierChain → List<String>
The complete chain of modifiers being applied
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
The schema type that failed to resolve
finalinherited
suggestions → List<String>?
Optional suggestions for resolving the failure
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited