RootItem class abstract interface

Represents a root item that is the root of a content tree.

Root items are special container items that serve as the entry point for a content tree. They typically represent:

  • Pages
  • Screens
  • Top-level content structures

Root items are directly managed by the content system and can be fetched by their unique identifiers.

Implemented types
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
layout → LayoutConfiguration<ContentItem>?
The layout configuration for the content item.
finalinherited
modifiers → List<ContentModifierConfiguration>?
finalinherited
parent ↔ ContentItem?
The parent content item of this content item. This is used internally by the content system.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
The schema type of the content item.
finalinherited

Methods

getLayout() → LayoutConfiguration<ContentItem>?
Gets the layout to use for the ContentItem. By default its the layout itself. However this acts as an extension point for custom ContentItems that may have a different strategy for applying layouts.
inherited
getModifiers() → List<ContentModifierConfiguration>?
Gets the modifiers to use for the ContentItem. By default its the modifiers itself. However this acts as an extension point for custom ContentItems that may have a different strategy for applying modifiers.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setParent(Iterable<ContentItem?> children) → void
Sets the parent content item for the given list of children.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited