SchemaItem class abstract interface

The base interface for all schema-driven content items.

Schema items are the foundation of Vyuh's content system. They represent any content that is defined by a schema in the CMS (Content Management System). All content items must implement this interface to be compatible with the content system.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
The schema type of the content item.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited