ContentProvider class abstract

Implementers

Constructors

ContentProvider({required String name, required String title, LiveContentProvider live = const NoOpLiveContentProvider()})

Properties

hashCode → int
The hash code for this object.
no setterinherited
live → LiveContentProvider
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsLive → bool
no setter
title → String
final

Methods

dispose() → Future<void>
fetchById<T>(String id, {required FromJsonConverter<T> fromJson, bool useCache = true}) → Future<T?>
fetchMultiple<T>(String query, {required FromJsonConverter<T> fromJson, Map<String, String>? queryParams, bool useCache = true}) → Future<List<T>?>
fetchRoute({String? path, String? routeId, bool useCache = true}) → Future<RouteBase?>
fetchSingle<T>(String query, {required FromJsonConverter<T> fromJson, Map<String, String>? queryParams, bool useCache = true}) → Future<T?>
fieldValue(String key, Map<String, dynamic> json) → String
fileUrl(FileReference fileRef) → Uri?
image(ImageReference imageRef, {int? width, int? height, int? devicePixelRatio, int? quality, String? format}) → ImageProvider<Object>?
init() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
schemaType(Map<String, dynamic> json) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited