NoOpLiveContentProvider class final

A no-op implementation of LiveContentProvider. Is used internally to ensure the Developer is using it correctly by giving proper errors and hints

Inheritance

Constructors

NoOpLiveContentProvider()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
The title of the live content provider.
finalinherited

Methods

dispose() → Future<void>
override
fetchById<T>(String id, {required FromJsonConverter<T> fromJson, bool includeDrafts = false}) → Stream<T?>
Fetches content by ID.
override
fetchMultiple<T>(String query, {required FromJsonConverter<T> fromJson, Map<String, String>? queryParams, bool includeDrafts = false}) → Stream<List<T>?>
Fetches content by query, returning a list of items.
override
fetchRoute({String? path, String? routeId, bool includeDrafts = false}) → Stream<RouteBase?>
Fetches content by route.
override
fetchSingle<T>(String query, {required FromJsonConverter<T> fromJson, Map<String, String>? queryParams, bool includeDrafts = false}) → Stream<T?>
Fetches content by query, returning a single item.
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited