LocalContentProvider class final

Inheritance

Constructors

LocalContentProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
live → LiveContentProvider
finalinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsLive → bool
no setterinherited
title → String
finalinherited

Methods

dispose() → Future<void>
override
fetchById<T>(String id, {required FromJsonConverter<T> fromJson, bool useCache = true}) → Future<T?>
override
fetchMultiple<T>(String query, {required FromJsonConverter<T> fromJson, Map<String, String>? queryParams, bool useCache = true}) → Future<List<T>?>
override
fetchRoute({String? path, String? routeId, bool useCache = true}) → Future<RouteBase?>
override
fetchSingle<T>(String query, {required FromJsonConverter<T> fromJson, Map<String, String>? queryParams, bool useCache = true}) → Future<T?>
override
fieldValue(String key, Map<String, dynamic> json) → String
override
fileUrl(FileReference fileRef) → Uri?
override
image(ImageReference imageRef, {int? width, int? height, int? devicePixelRatio, int? quality, String? format}) → ImageProvider<Object>?
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
schemaType(Map<String, dynamic> json) → String
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited