RouteLifecycleConfiguration class abstract

Configuration for managing route lifecycle events.

Route lifecycle configurations handle the initialization and cleanup of route-specific resources. They can:

  • Load route-specific data
  • Set up route state
  • Clean up resources
  • Handle route-specific events

Example:

class BlogLifecycle extends RouteLifecycleConfiguration {
  @override
  Future<void> init(BuildContext context, RouteBase route) async {
    await loadBlogData();
  }

  @override
  Future<void> dispose() async {
    await saveBlogState();
  }
}
Implemented types

Constructors

RouteLifecycleConfiguration({String? title, required String schemaType})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → String
The schema type of the content item.
final
title → String?
final

Methods

dispose() → Future<void>
init(BuildContext context, RouteBase route) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited