DefaultEnvPlugin class final

Inheritance

Constructors

DefaultEnvPlugin({String fileName = '.env', Map<String, String> defaults = const {}})

Properties

defaults → Map<String, String>
final
fileName → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
finalinherited

Methods

all() → Map<String, String>
Returns a map of all environment variables.
override
clear() → void
Clears all the environment variables.
override
dispose() → Future<void>
override
get(String key, {String? fallback}) → String
Returns the value of the environment variable specified by key, or the fallback value if not found.
override
init() → Future<void>
override
maybeGet(String key, {String? fallback}) → String?
Returns the value of the environment variable specified by key, or the fallback value if not found, or null if neither is found.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited