EnvPlugin class abstract

An abstract class representing an environment plugin. It provides methods to interact with environment variables.

Inheritance
Implementers

Constructors

EnvPlugin({required String name, required String title})
Constructs an EnvPlugin with the given name and title.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
finalinherited

Methods

all() → Map<String, String?>
Returns a map of all environment variables.
clear() → void
Clears all the environment variables.
dispose() → Future<void>
inherited
get(String key, {String? fallback}) → String
Returns the value of the environment variable specified by key, or the fallback value if not found.
init() → Future<void>
inherited
maybeGet(String key, {String? fallback}) → String?
Returns the value of the environment variable specified by key, or the fallback value if not found, or null if neither is found.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited