DefaultNavigationPlugin class final

Inheritance

Constructors

DefaultNavigationPlugin({bool includeFallbackRoute = true, bool urlReflectsImperativeAPIs = false, GoRouterRedirect? redirect})

Properties

hashCode → int
The hash code for this object.
no setterinherited
includeFallbackRoute → bool
final
instance → GoRouter
no setteroverride
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
finalinherited

Methods

appendInitialRoutes(List<RouteBase> routes) → void
override
appendRoutes(List<RouteBase> routes) → void
override
dispose() → Future<void>
override
go(String location, {Object? extra}) → void
override
goNamed(String name, {Map<String, String> pathParameters = const <String, String>{}, Map<String, dynamic> queryParameters = const <String, dynamic>{}, Object? extra}) → void
override
init() → Future<void>
override
initRouter({String? initialLocation, required List<RouteBase> routes, required GlobalKey<NavigatorState> rootNavigatorKey}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop<T extends Object?>([T? result]) → void
override
push<T extends Object?>(String location, {Object? extra}) → Future<T?>
override
pushNamed<T extends Object?>(String name, {Map<String, String> pathParameters = const <String, String>{}, Map<String, dynamic> queryParameters = const <String, dynamic>{}, Object? extra}) → Future<T?>
override
pushReplacement<T extends Object?>(String location, {Object? extra}) → Future<T?>
override
pushReplacementNamed<T extends Object?>(String name, {Map<String, String> pathParameters = const <String, String>{}, Map<String, dynamic> queryParameters = const <String, dynamic>{}, Object? extra}) → Future<T?>
override
replace<T extends Object?>(String location, {Object? extra}) → Future<T?>
override
replaceNamed<T extends Object?>(String name, {Map<String, String> pathParameters = const <String, String>{}, Map<String, dynamic> queryParameters = const <String, dynamic>{}, Object? extra}) → Future<T?>
override
replaceRoutes(List<RouteBase> routes) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

enableURLReflectsImperativeAPIs() → void
setRouterRedirect(GoRouterRedirect redirect) → void
useHashStrategy() → void
usePathStrategy() → void