InitOncePlugin mixin

Initializes a plugin once per active lifecycle, sharing concurrent calls.

Disposal waits for initialization, releases resources once, and allows a new lifecycle. Failed initialization can be retried. This can be combined with PreloadedPlugin to select the initialization stage.

Superclass constraints
Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialized → bool
no setter
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
finalinherited

Methods

dispose() → Future<void>
override
disposeOnce() → Future<void>
init() → Future<void>
override
initOnce() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited