LogLevel enum

Inheritance
Available extensions

Values

debug → const LogLevel

The log level for debug messages.

info → const LogLevel

The log level for info messages. This is the default level.

trace → const LogLevel

The log level for trace messages. These are generally used for fine-grained debugging.

warning → const LogLevel

The log level for warning messages. Use this for guiding the developer on correct usage of the concerned API.

error → const LogLevel

The log level for error messages. Use this for exceptions and errors.

fatal → const LogLevel

The log level for fatal messages. This is only for the most severe errors, generally considered irrecoverable.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.