TelemetryPlugin class final

The default implementation for a Telemetry Plugin.

Inheritance
Implemented types
Mixed-in types

Constructors

TelemetryPlugin({required List<TelemetryProvider> providers})
Creates a new TelemetryPlugin.

Properties

description → String
The description of the provider.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
initialized → bool
no setterinherited
name → String
finalinherited
providers → List<TelemetryProvider>
The list of providers for the plugin.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
finalinherited

Methods

dispose() → Future<void>
inherited
disposeOnce() → Future<void>
override
init() → Future<void>
inherited
initOnce() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportError(dynamic exception, {StackTrace? stackTrace, Map<String, dynamic>? params, bool fatal = false}) → Future<void>
Reports an error with an optional stack trace and parameters.
override
reportFlutterError(FlutterErrorDetails details, {bool fatal = false}) → Future<void>
Reports a Flutter error with optional parameters.
override
reportMessage(String message, {Map<String, dynamic>? params, LogLevel? level = LogLevel.info}) → Future<void>
Reports a message with optional parameters.
override
startTrace(String name, String operation, {LogLevel? level = LogLevel.info}) → Future<Trace>
Starts a trace with a specific name and operation.
override
toString() → String
A string representation of this object.
inherited
trace<T>({required String name, required String operation, required FutureOr<T?> fn(Trace? parentTrace), Trace? parentTrace, LogLevel? level = LogLevel.info}) → Future<T?>
Runs a function with a trace. This is useful for wrapping functions that need to be traced. It can also be part of a nested trace, using the parentTrace parameter.

Operators

operator ==(Object other) → bool
The equality operator.
inherited