TelemetryProvider class abstract interface

The base interface for an Telemetry Provider. The provider is responsible for reporting telemetry events, errors, and messages.

Implementers

Properties

description → String
The description of the provider.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the provider.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
The title of the provider.
no setter

Methods

dispose() → Future<void>
Disposes the provider.
init() → Future<void>
Initializes the provider.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportError(dynamic exception, {StackTrace? stackTrace, Map<String, dynamic>? params, bool fatal = false}) → Future<void>
Reports an error with an optional stack trace and parameters.
reportFlutterError(FlutterErrorDetails details, {bool fatal = false}) → Future<void>
Reports a Flutter error with optional parameters.
reportMessage(String message, {Map<String, dynamic>? params, LogLevel? level = LogLevel.info}) → Future<void>
Reports a message with optional parameters.
startTrace(String name, String operation, {LogLevel? level = LogLevel.info}) → Future<Trace>
Starts a trace with a specific name and operation.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited