Trace class abstract

The base interface for a Telemetry Trace. The trace is responsible for tracking the duration of an operation, and reporting metrics and attributes.

Implementers

Constructors

Trace()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAttributes() → Map<String, String>
Gets all attributes set so far in the trace.
getMetric(String name) → int
Gets a metric with a specific name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttributes(Map<String, String> attributes) → void
Sets an attribute with a specific name and value.
setMetric(String name, int value) → void
Sets a metric with a specific name and value.
startChild(String name, String operation, {LogLevel? level = LogLevel.info}) → Future<Trace>
Starts a child trace with a specific name and operation.
stop() → Future<void>
Stops or finalizes the trace.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited