SystemInitTracker class abstract interface

A tracker for the system initialization process.

Properties

currentState → Observable<InitState>
The current state of the initialization process.
no setter
error → dynamic
The error that occurred during initialization.
no setter
hashCode → int
The hash code for this object.
no setterinherited
platform → VyuhPlatform
The platform that is being initialized.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → FutureStatus?
The status of the future that is being awaited.
no setter

Methods

init([InitState initialState]) → Future<void>
Initializes the system.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited