RouteErrorViewBuilder typedef

RouteErrorViewBuilder = Widget Function(BuildContext context, {dynamic error, VoidCallback? onRetry, String? retryLabel, StackTrace? stackTrace, String? subtitle, required String title})

A builder for a route error view widget.

This builder is called when an error occurs during route navigation. It provides detailed error information and optional retry functionality.

Example:

RouteErrorViewBuilder builder = (
  context, {
  required title,
  retryLabel,
  onRetry,
  error,
  stackTrace,
  subtitle,
}) => ErrorView(
  title: title,
  subtitle: subtitle,
  onRetry: onRetry,
);

Implementation

typedef RouteErrorViewBuilder =
    Widget Function(
      BuildContext context, {
      required String title,
      String? retryLabel,
      VoidCallback? onRetry,
      dynamic error,
      StackTrace? stackTrace,
      String? subtitle,
    });