plugin/storage/storage library
Classes
- InMemorySecureStoragePlugin
- A simple in-memory secure storage plugin that stores data in a Map.
- InMemoryStoragePlugin
- A simple in-memory storage plugin that stores data in a Map.
- SecureStoragePlugin
- A storage contract for app-selected secure storage implementations.
- StoragePlugin
- A key-value storage capability shared by features.