metadata property
Application-defined metadata associated with this route.
This can be used to attach static information that is useful while
building the matched page, such as analytics labels, page titles,
permissions, or feature flags. The merged metadata for the current match
is available from GoRouterState.metadata.
Metadata is inherited from parent routes and child route values override parent values with the same key.
Implementation
final Map<String, dynamic>? metadata;