runtime/run_app library
Classes
Extensions
Functions
-
defaultAppRunner(
Widget app) → void - The default app runner that initializes Flutter bindings and runs the app using flutter.runApp.
-
runApp(
{required FeaturesBuilder features, LazyFeaturesBuilder? lazyFeatures, PluginDescriptor? plugins, PlatformWidgetBuilder? platformWidgetBuilder, String? initialLocation, AppRunner? appRunner}) → void - The main entry point to kick off the Vyuh Application. This function should be called from the main function of the application. It initializes the Vyuh Platform and runs the application with given features and plugins.
Typedefs
- AppRunner = void Function(Widget app)
- A function that takes a Widget and runs the application.
-
LazyFeaturesBuilder
= List<
LazyFeatureDescriptor> Function() - A builder that returns lazy feature descriptors.